@@ -7,7 +7,7 @@ use HTML::Entities qw(decode_entities);
 
 our @ISA = qw(WWW::Scraper::ISBN::Driver);
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
                 
 sub search {
         my $self = shift;
@@ -49,14 +49,14 @@ sub search {
 		$price = $1 if ($doc =~ /Prezzo: .*?&euro;&nbsp;(\d+)/);
 	} elsif ($doc =~ /Dettagli del libro/){
 		$price = $1 if ($doc =~ m|<span class="product_price">&euro;&nbsp;([^<]+)</span>|);
-		$title = $1 if ($doc =~ m|<span class="product_label">Titolo:</span> <span class="product_text">([^>]+)</span>|);
-		$authors = parse_authors($1) if ($doc =~ m|<span class="product_label">Autor[ei]:</span>(.*?)<li>|);
-	    $editor = $1 if ($doc =~ m|<span class="product_label">Editore:</span>\s+<span class="product_text"><a href="libri-editore[^>]+>([^<]+)</a>|);
-		$date = $1 if ($doc =~ m|<span class="product_label">Data di Pubblicazione:</span>\s+<span class="product_text">(\d+)</span><li>|);
-		$pages = $1 if ($doc =~ m|<span class="product_label">Pagine:</span>\s+<span class="product_text">(\d+)</span><li>|);
-        $series = $1 if ($doc =~ m|<span class="product_label">Collana:</span>\s+<span class="product_text"><a href="libri-collana[^>]+>([^<]+)</a>|);
-	    $shelf = $1 if ($doc =~ m|<span class="product_label">Reparto:</span>\s+<span class="product_text"><a class="" href="libri[^>]+>([^<]+)</a>|);
-	    $trans = $1 if ($doc =~ m|<span class="product_label">Traduttore:</span>\s+<span class="product_text">([^<]+)</span><li>|);
+		$title = $1 if ($doc =~ m|<span class="product_label">Titolo: </span>\n\t+\s+<span class="product_text">([^>]+)</span>|);
+		$authors = parse_authors($1) if ($doc =~ m|<span class="product_label">Autor[ei]: </span>\n\t+\s+(.*?)\n\t+\s+</li>|);
+	    $editor = $1 if ($doc =~m|<span class="product_label">Editore: </span>\n\t+\s+<span class="product_text"><a class="publisher_url_html" href="http://www.libreriauniversitaria.it/libri-editore[^>]+>([^<]+)</a>|);
+	    $date = $1 if ($doc =~ m|<span class="product_label">Data di Pubblicazione: </span>\n\t+\s+<span class="product_text">(\d+)</span>|);
+		$pages = $1 if ($doc =~ m|<span class="product_label">Pagine: </span>\n\t+\s+<span class="product_text">(\d+)</span>|);
+        $series = $1 if ($doc =~ m|<span class="product_label">Collana: </span>\n\t+\s+<span class="product_text"><a class="publisher_url_html" href="http://www.libreriauniversitaria.it/libri-collana[^>]+>([^<]+)</a>|);
+	    $shelf = $1 if ($doc =~ m|<span class="product_label">Reparto: </span>\n\t+\s+<span class="product_text"><a class="reparto_url_html" href="http://www.libreriauniversitaria.it/libri[^>]+>([^<]+)</a>|);
+	    $trans = $1 if ($doc =~ m|<span class="product_label">Traduttore: </span>\n\t+\s+<span class="product_text">([^<]+)</span><li>|);
 	    
 	} else {
 		$self->error("libreriauniversitaria.it answered in an unattended way, book information cannot be found.");
@@ -87,7 +87,7 @@ sub parse_authors {
 	my $info = shift;
 	my $sep = "";
 	my $authors;
-	while ($info =~ s|<a href="libri-autore[^"]+" [^>]+>([^<]+)</a>||){
+	while ($info =~ s|<a class="authors_url_html" href="http://www.libreriauniversitaria.it/libri-autore[^"]+" [^>]+>([^<]+)</a>||){
 		$authors .=  $sep . $1;
 		$sep = ", ";
 	}
